<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bn_BD">
<context>
    <name>ClipGrab</name>
    <message>
        <location filename="clipgrab.cpp" line="36"/>
        <source>Automatic language recognition</source>
        <translation>ভাষার স্বয়ংক্রিয় চিহ্নিতকরণ</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="512"/>
        <source>Downloading update … %1/%2 MBytes</source>
        <translation>আপডেট ডাউনলোড হচ্ছে … %1/%2 MBytes</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="521"/>
        <source>There was an error while downloading the update.: %1</source>
        <translation>আপডেট ডাউনলোড করাকালীন কোনো সমস্যা হয়েছে।: %1</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="535"/>
        <source>The fingerprint of the downloaded update file could not be verified: %1 should have been %2</source>
        <translation>ডাউনলোডকৃত আপডেট ফাইলের ফিঙ্গারপ্রিন্ট সত্যায়ন করা যায় নি: %1 হওয়া উচিত %2</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="547"/>
        <source>Could not open update file.</source>
        <translatorcomment>Bangla (Bengali) symbol for Full Stop is ।</translatorcomment>
        <translation>আপডেট ফাইল খোলা যায় নি।</translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="585"/>
        <source>Unable to write to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="607"/>
        <source>SSL error: %1 
%2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="614"/>
        <source>Error downloading youtube-dl: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>MiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>GiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="clipgrab.cpp" line="805"/>
        <source>TiB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadListModel</name>
    <message>
        <location filename="download_list_model.cpp" line="99"/>
        <source>Starting ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="106"/>
        <source>Converting ...</source>
        <translation type="unfinished">রূপান্তর হচ্ছে ...</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="108"/>
        <source>Finished</source>
        <translation type="unfinished">সমাপ্ত</translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="110"/>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="112"/>
        <source>Canceled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="114"/>
        <source>Waiting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.cpp" line="116"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Portal</source>
        <translation type="unfinished">পোর্টাল</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Title</source>
        <translation type="unfinished">শিরোনাম</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Format</source>
        <translation type="unfinished">ধরন</translation>
    </message>
    <message>
        <location filename="download_list_model.h" line="37"/>
        <source>Progress</source>
        <translation type="unfinished">উন্নতি</translation>
    </message>
</context>
<context>
    <name>HelperDownloader</name>
    <message>
        <location filename="helper_downloader.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished">ডায়ালগ</translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="20"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="27"/>
        <source>Exit ClipGrab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="85"/>
        <source>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to download youtube-dl.&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;ClipGrab uses youtube-dl in order to download videos from the Internet. youtube-dl is developed by an independent team of Open Source developers and released into the public domain.&lt;br&gt;Learn more on &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Click on &lt;em&gt;Continue&lt;/em&gt; to automatically download youtube-dl.&lt;/p&gt;</oldsource>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="helper_downloader.ui" line="99"/>
        <source>Downloading youtube-dl</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="273"/>
        <source>Select Target</source>
        <translation>কাঙ্ক্ষিতটি নির্বাচন করুন</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="74"/>
        <source>Please wait while ClipGrab is loading information about the video ...</source>
        <translation>ClipGrab ভিডিওটির তথ্য ডাউনলোড করাকালীন দয়া করে অপেক্ষা করুন ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>যে ভিডিওটি ডাউনলোড করতে চান দয়া করে সেটির লিঙ্ক নিচের ঘরে দিন।</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>No downloadable video could be found.&lt;br /&gt;Maybe you have entered the wrong link or there is a problem with your connection.</source>
        <translation>ডাউনলোডের উপযোগী কোনো ভিডিও পাওয়া যায় নি।&lt;br /&gt;সম্ভবত ভুল লিঙ্ক প্রবেশ করিয়েছেন বা সংযোগে কোনো সমস্যা আছে।</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="376"/>
        <source>ClipGrab - Select target path</source>
        <translation>ClipGrab - কাঙ্ক্ষিত পথ নির্বাচন করুন</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab: Video discovered in your clipboard</source>
        <translation>ClipGrab: ক্লিপবোর্ডে পাওয়া ভিডিও</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="415"/>
        <source>ClipGrab has discovered the address of a compatible video in your clipboard. Click on this message to download it now.</source>
        <translation>ClipGrab ক্লিপবোর্ডে একটি সমর্থিত ভিডিওর ঠিকানা পেয়েছে। এক্ষুণি এটি ডাউনলোড করতে এই বার্তাটিতে ক্লিক করুন।</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>ClipGrab - Exit confirmation</source>
        <translation>ClipGrab - প্রস্থান নিশ্চিতকরণ</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>There is still at least one download in progress.&lt;br /&gt;If you exit the program now, all downloads will be canceled and cannot be recovered later.&lt;br /&gt;Do you really want to quit ClipGrab now?</source>
        <translation>এখনও অন্তত একটি ডাউনলোড চলমান আছে।&lt;br /&gt;প্রোগ্রামটি এখন বন্ধ করলে সব ডাউনলোড বাতিল হবে এবং পরে পুনরুদ্ধার করা যাবে না।&lt;br /&gt;আসলেই কি ClipGrab এখন বন্ধ করতে চান?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Download finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="527"/>
        <source>Downloading and converting “%title” is now finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>All downloads finished</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="529"/>
        <source>ClipGrab has finished downloading and converting all selected videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="683"/>
        <source>No results found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>&amp;Open downloaded file</source>
        <translatorcomment>ডাউনলোডকৃত ফাইল খুলুন (&amp;O)</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="741"/>
        <source>Open &amp;target folder</source>
        <translation>কাঙ্ক্ষিত ফোল্ডার খুলুন (&amp;t)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="743"/>
        <source>&amp;Pause download</source>
        <translation>ডাউনলোড স্থগিত করো (&amp;P)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="744"/>
        <source>&amp;Restart download</source>
        <translation>ডাউনলোড আবার শুরু করো (&amp;R)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="745"/>
        <source>&amp;Cancel download</source>
        <translation>ডাউনলোড বাতিল (&amp;C)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="747"/>
        <source>Copy &amp;video link</source>
        <translation>ভিডিও লিঙ্ক কপি করো (&amp;v)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="748"/>
        <source>Open video link in &amp;browser</source>
        <translation>ভিডিও লিঙ্ক ব্রাউজারে খোল (&amp;b)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="751"/>
        <source>Resume download</source>
        <translation>ডাউনলোড রিজিউম করো</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="764"/>
        <source>Show in &amp;Finder</source>
        <translation>ফাইন্ডারে দেখাও (&amp;F)</translation>
    </message>
</context>
<context>
    <name>MainWindowClass</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>ClipGrab - Download and Convert Online Videos</source>
        <translation>ClipGrab - অনলাইন ভিডিওসমূহ ডাউনলোড ও রূপান্তর করুন</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="153"/>
        <source>Search</source>
        <translation>খুঁজুন</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Enter keywords in the box below in order to search videos on YouTube</source>
        <translation>YouTube-এ ভিডিও খুঁজতে নিচের বক্সে সম্পর্কিত শব্দাবলী লিখুন</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Downloads</source>
        <translation>ডাউনলোডসমূহ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="199"/>
        <source>Grab this clip!</source>
        <translation>ক্লিপটি লুফে নাও!</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="234"/>
        <source>Quality:</source>
        <translation>মান:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>Please enter the link to the video you want to download in the field below.</source>
        <translation>যে ভিডিওটি ডাউনলোড করতে চান সেটির লিঙ্ক নিচের ঘরে দিন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="291"/>
        <source>Format:</source>
        <translation>ধরন:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="343"/>
        <source>Current Downloads:</source>
        <translation>বর্তমান ডাউনলোডসমূহ:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="363"/>
        <source>Cancel selected download</source>
        <translation>নির্বাচিত ডাউনলোড বাতিল করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="353"/>
        <source>Open the target folder of the selected download</source>
        <translation>নির্বাচিত ডাউনলোডের কাঙ্ক্ষিত ফোল্ডার খোল</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="373"/>
        <source>Pause selected download</source>
        <translation>নির্বাচিত ডাউনলোড স্থগিত করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="385"/>
        <source>Settings</source>
        <translation>সেটিংস্‌</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>General</source>
        <translation>সাধারণ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="422"/>
        <source>Here you can adjust some general settings concerning the behaviour of ClipGrab.</source>
        <translation>ClipGrab এর কাজের সাথে সম্পর্কিত কিছু সাধারণ সেটিংস্‌ এখান থেকে সমন্বয় করা যাবে।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="433"/>
        <source>Target Path</source>
        <translation>রূপান্তর</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="439"/>
        <source>Always save at the last used path.</source>
        <translation>সবসময় সর্বশেষ ব্যবহৃত জায়গায় সেভ করো।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="453"/>
        <source>Here you can configure where the downloaded videos are to be saved.</source>
        <translation>ডাউনলোড হওয়া ভিডিওগুলো কোথায় সেভ হবে তা এখান থেকে ঠিক করে নিতে পারবেন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <source>Browse ...</source>
        <translation>ব্রাউজ ...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>Never ask for file name</source>
        <translation>ফাইলের নাম কখনও জানতে চেয়ো না</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="488"/>
        <source>Metadata</source>
        <translation>আনুষঙ্গিক উপাত্ত</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="494"/>
        <source>Here you can configure if ClipGrab is supposed to add metadata (ID3 tags) to your mp3 files.</source>
        <translation>ClipGrab আপনার mp3 ফাইলগুলোতে আনুষঙ্গিক উপাত্ত (ID3-tags) যোগ করবে কিনা তা এখান থেকে ঠিক করে দিতে পারবেন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="501"/>
        <source>Use metadata</source>
        <translation>আনুষঙ্গিক উপাত্ত ব্যবহার করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="522"/>
        <source>Clipboard</source>
        <translation>ক্লিপবোর্ড</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="528"/>
        <source>Here you can configure how ClipGrab behaves when a downloadable video is discovered in your clipboard.</source>
        <translation>যখন ক্লিপবোর্ডে কোনো ডাউনলোডযোগ্য ভিডিও পাওয়া যাবে তখন ClipGrab কী করবে তা এখান থেকে ঠিক করে দিতে পারবেন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="535"/>
        <source>Always download</source>
        <translation>সবসময় ডাউনলোড করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Never download</source>
        <translation>কখনও ডাউনলোড করো না</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="549"/>
        <source>Always ask</source>
        <translation>সবসময় জিজ্ঞেস করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="570"/>
        <source>Notifications</source>
        <translation>প্রজ্ঞাপনসমূহ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <source>After each download</source>
        <translation>প্রত্যেক ডাউনলোডের পর</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="583"/>
        <source>After all downloads have been completed</source>
        <translation>সব ডাউনলোড সম্পন্ন হওয়ার পর</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="603"/>
        <source>Here you can configure when ClipGrab is supposed to display notifications.</source>
        <translation>ClipGrab কখন প্রজ্ঞাপনসমূহ দেখাবে তা এখান থেকে ঠিক করে দিতে পারবেন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="610"/>
        <source>Never</source>
        <translation>কখনও না</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="618"/>
        <source>Proxy</source>
        <translation>প্রক্সি</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <source>Use a proxy server</source>
        <translation>প্রক্সি সার্ভার ব্যবহার করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Proxy settings</source>
        <translation>প্রক্সি সেটিংস্‌</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="643"/>
        <source>Hostname/IP:</source>
        <translation>হোস্টনেম/আইপি:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="650"/>
        <source>Port:</source>
        <translation>পোর্ট:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="677"/>
        <source>Proxy type:</source>
        <translation>প্রক্সির ধরন:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="685"/>
        <source>HTTP Proxy</source>
        <translation>HTTP প্রক্সি</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="690"/>
        <source>Socks5 Proxy</source>
        <translation>Socks5 প্রক্সি</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="717"/>
        <source>Proxy authentication</source>
        <translation>প্রক্সি যাচাইকরণ</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="723"/>
        <source>Username:</source>
        <translation>ইউজারনেম:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="740"/>
        <source>Password:</source>
        <translation>পাসওয়ার্ড:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <source>Proxy requires authentication</source>
        <translation>প্রক্সির জন্য যাচাইকরণ প্রয়োজনীয়</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="761"/>
        <source>Other</source>
        <translation>অন্যান্য</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="788"/>
        <source>Remove finished downloads from list</source>
        <translation>সম্পন্ন ডাউনলোডসমূহ তালিকা থেকে সরাও</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1182"/>
        <source>&lt;h2&gt;Thanks&lt;/h2&gt;
ClipGrab relies on the work of the Qt project, the ffmpeg team, and the youtube-dl team.&lt;br&gt;
Visit &lt;a href=&quot;https://www.qt.io&quot;&gt;qt.io&lt;/a&gt;, &lt;a href=&quot;https://ffmpeg.org&quot;&gt;ffmpeg.org&lt;/a&gt;, and &lt;a href=&quot;https://youtube-dl.org&quot;&gt;youtube-dl.org&lt;/a&gt; for further information.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="767"/>
        <source>Minimize ClipGrab to the system tray</source>
        <translation>সিস্টেম ট্রেতে ClipGrab ছোট করে রাখো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="774"/>
        <source>Use WebM if possible</source>
        <translation>সম্ভব হলে WebM ব্যবহার করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="781"/>
        <source>Ignore SSL errors</source>
        <translation>SSL ত্রুটিসমূহ উপেক্ষা করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="808"/>
        <source>Remember logins</source>
        <translation>লগইনসমূহ মনে রাখো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="815"/>
        <source>Remember video quality</source>
        <translation>ভিডিও মান মনে রাখো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="827"/>
        <source>Language</source>
        <translation>ভাষা</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="851"/>
        <source>Here you can change the language of ClipGrab.</source>
        <translatorcomment>Full Stop= ।</translatorcomment>
        <translation>এখান থেকে ClipGrab এর ভাষা বদলাতে পারবেন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="858"/>
        <source>Please select a language from the list below. You have to restart ClipGrab in order to apply you selection.</source>
        <translation>দয়া করে নিচের তালিকা থেকে ভাষা বাছাই করুন। বাছাই কার্যকর করতে ClipGrab আবার চালু করতে হবে।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="895"/>
        <source>Conversion</source>
        <translation>রূপান্তর</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="918"/>
        <source>Experts can create custom presets for the video conversion here.</source>
        <translation>ভিডিও রূপান্তরের জন্য অভিজ্ঞরা এখান থেকে পছন্দসই পূর্বমান তৈরি করতে পারবেন।</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="925"/>
        <source>Format preset</source>
        <translation>ধরন এর পূর্বমান</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="935"/>
        <source>Add new preset</source>
        <translation>নতুন পূর্বমান যোগ করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="942"/>
        <source>Remove selected preset</source>
        <translation>বাছাইকৃত পূর্বমান সরাও</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="965"/>
        <source>Audio</source>
        <translation>অডিও</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="977"/>
        <location filename="mainwindow.ui" line="1029"/>
        <source>Codec</source>
        <translation>কোডেক</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1003"/>
        <location filename="mainwindow.ui" line="1091"/>
        <source>Bitrate (kb/s)</source>
        <translation>বিটরেট (kb/s)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1010"/>
        <source>Disable Audio</source>
        <translation>অডিও নিষ্ক্রিয় করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1020"/>
        <source>Video</source>
        <translation>ভিডিও</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1042"/>
        <source>Frames/second</source>
        <translation>ফ্রেম/সেকেন্ড</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1101"/>
        <source>Disable video</source>
        <translation>ভিডিও নিষ্ক্রিয় করো</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1116"/>
        <source>About</source>
        <translation>পরিচিতি</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1122"/>
        <source>&lt;h2&gt;Support ClipGrab!&lt;/h2&gt;
&lt;p&gt;Only with your support, ClipGrab can remain free software!&lt;br&gt;So if you like ClipGrab and also want to help ensuring its further development, please consider making a donation.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;ClipGrab-কে সমর্থন দিন!&lt;/h2&gt;
&lt;p&gt;শুধু আপনাদের সমর্থনের মাধ্যমেই ClipGrab ফ্রি সফটওয়্যার হিসেবে টিকে থাকতে পারে!&lt;br&gt; তাই ClipGrab পছন্দ হলে ও এর আরও উন্নয়ন নিশ্চিত করতে দয়া করে ডোনেশন প্রদানের বিষয়টি বিবেচনা করুন।&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1165"/>
        <source>&lt;h2&gt;Translation&lt;/h2&gt;
ClipGrab is already available in many languages. If ClipGrab has not been translated into your language yet and if you want to contribute a translation, please check &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt; for further information.</source>
        <translation>&lt;h2&gt;অনুবাদ&lt;/h2&gt;
ClipGrab ইতোমধ্যে অনেক ভাষাতে সুলভ। যদি ClipGrab আপনার ভাষাতে এখনও অনূদিত না হয়ে থাকে আর আপনি অনুবাদে অবদান রাখতে চান, আরও তথ্যের জন্য দয়া করে &lt;a href=&quot;http://clipgrab.de/translate&quot;&gt;http://clipgrab.de/translate&lt;/a&gt;  -এ দেখুন।</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="metadata-dialog.ui" line="14"/>
        <source>ClipGrab - enter metadata</source>
        <translation>ClipGrab - আনুষঙ্গিক উপাত্ত দিন</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="25"/>
        <source>Please enter the metadata for your download. If you don&apos;t want to add metadata, just leave the fields empty.</source>
        <translatorcomment>comma isn&apos;t necessary in the translation</translatorcomment>
        <translation>ডাউনলোডের জন্য আনুষঙ্গিক উপাত্ত দিন দয়া করে। আনুষঙ্গিক উপাত্ত না দিতে চাইলে ঘরগুলো খালি রাখুন।</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="45"/>
        <source>Title:</source>
        <translation>শিরোনাম:</translation>
    </message>
    <message>
        <location filename="metadata-dialog.ui" line="52"/>
        <source>Artist:</source>
        <translation>শিল্পী:</translation>
    </message>
</context>
<context>
    <name>UpdateMessage</name>
    <message>
        <location filename="update_message.ui" line="14"/>
        <source>Update for ClipGrab</source>
        <translation>ClipGrab এর আপডেট</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="116"/>
        <source>ClipGrab %1 is now available (you are using %2). Would you like to install the update?</source>
        <translation>ClipGrab %1 এখন সুলভ (আপনি %2 ব্যবহার করছেন)। আপডেটটি ইন্সটল করতে চান?</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="130"/>
        <source>There is an update for your version of ClipGrab!</source>
        <translation>আপনার ClipGrab ভার্সনের জন্য আপডেট পাওয়া গেছে!</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="64"/>
        <source>Skip this update</source>
        <translation>এই আপডেট এড়িয়ে যাও</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="91"/>
        <source>Download update</source>
        <translation>ডাউনলোড আপডেট</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="240"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="74"/>
        <source>Remind me later</source>
        <translation>পরে মনে করাও</translation>
    </message>
    <message>
        <location filename="update_message.ui" line="41"/>
        <source>The update will begin in just a moment …</source>
        <translation>কিছুক্ষণের মধ্যেই ডাউনলোড শুরু হবে ...</translation>
    </message>
</context>
<context>
    <name>converter_copy</name>
    <message>
        <location filename="converter_copy.cpp" line="28"/>
        <source>Original</source>
        <translation>প্রকৃত</translation>
    </message>
</context>
<context>
    <name>converter_ffmpeg</name>
    <message>
        <location filename="converter_ffmpeg.cpp" line="216"/>
        <source>MPEG4</source>
        <translation>MPEG4</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="217"/>
        <source>WMV (Windows)</source>
        <translation>WMV (Windows)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="218"/>
        <source>OGG Theora</source>
        <translation>OGG Theora</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="219"/>
        <source>MP3 (audio only)</source>
        <translation>MP3 (শুধু অডিও)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="220"/>
        <source>OGG Vorbis (audio only)</source>
        <translation>OGG Vorbis (শুধু অডিও)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="221"/>
        <source>Original (audio only)</source>
        <translation>প্রকৃত (শুধু অডিও)</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="356"/>
        <source>No installed version of avconv or ffmpeg coud be found. Converting files and downloading 1080p videos from YouTube is not supported.</source>
        <translation>avconv বা ffmpeg এর কোনো ইন্সটলড্‌ ভার্সন পাওয়া যায় নি। YouTube থেকে 1080p ভিডিওসমূহ ডাউনলোড ও রূপান্তর করা যাবে না।</translation>
    </message>
    <message>
        <location filename="converter_ffmpeg.cpp" line="371"/>
        <source>The installed version of %1 is outdated.
Downloading 1080p videos from YouTube is not supported.</source>
        <translation>%1 এর ইন্সটলড্‌ ভার্সনটি সেকেলে।
YouTube থেকে 1080p ভিডিওসমূহ ডাউনলোড করা যাবে না।</translation>
    </message>
</context>
<context>
    <name>messageDialog</name>
    <message>
        <location filename="message_dialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>ডায়ালগ</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="48"/>
        <source>Close this message</source>
        <translation>বার্তাটি বন্ধ করুন</translation>
    </message>
    <message>
        <location filename="message_dialog.ui" line="71"/>
        <source>about:blank</source>
        <translation>about:blank</translation>
    </message>
</context>
<context>
    <name>video</name>
    <message>
        <location filename="video.cpp" line="261"/>
        <source>unknown</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
